@@ -37,19 +37,17 @@ as_gt <- function(x, ...) {
 #' library(tibble)
 #'
 #' # Enrollment rate
-#' enroll_rate <- tibble(
-#'   stratum = "All",
+#' enroll_rate <- define_enroll_rate(
 #'   duration = 18,
 #'   rate = 20
 #' )
 #'
 #' # Failure rates
-#' fail_rate <- tibble(
-#'   stratum = "All",
+#' fail_rate <- define_fail_rate(
 #'   duration = c(4, 100),
 #'   fail_rate = log(2) / 12,
-#'   hr = c(1, .6),
-#'   dropout_rate = .001
+#'   dropout_rate = .001,
+#'   hr = c(1, .6)
 #' )
 #'
 #' # Study duration in months
@@ -68,8 +66,7 @@ as_gt <- function(x, ...) {
 #' #        AHR                #
 #' # ------------------------- #
 #' # under fixed power
-#' fixed_design(
-#'   "ahr",
+#' fixed_design_ahr(
 #'   alpha = alpha, power = 1 - beta,
 #'   enroll_rate = enroll_rate, fail_rate = fail_rate,
 #'   study_duration = study_duration, ratio = ratio
@@ -81,8 +78,7 @@ as_gt <- function(x, ...) {
 #' #        FH                 #
 #' # ------------------------- #
 #' # under fixed power
-#' fixed_design(
-#'   "fh",
+#' fixed_design_fh(
 #'   alpha = alpha, power = 1 - beta,
 #'   enroll_rate = enroll_rate, fail_rate = fail_rate,
 #'   study_duration = study_duration, ratio = ratio
@@ -155,14 +151,14 @@ as_gt.fixed_design <- function(x, title = NULL, footnote = NULL, ...) {
       "fh" = {
         paste0(
           "Power for Fleming-Harrington test ",
-          substr(x$design, 19, nchar(x$design)),
+          substr(x$Design, 19, nchar(x$Design)),
           " using method of Yung and Liu."
         )
       },
       "mb" = {
         paste0(
           "Power for ",
-          x$design,
+          x$Design,
           " computed with method of Yung and Liu."
         )
       },
@@ -176,20 +172,19 @@ as_gt.fixed_design <- function(x, title = NULL, footnote = NULL, ...) {
       "maxcombo" = {
         paste0(
           "Power for MaxCombo test with Fleming-Harrington tests",
-          substr(x$design, 9, nchar(x$design)), "."
+          substr(x$Design, 9, nchar(x$Design)), "."
         )
       },
       "milestone" = {
-        paste0("Power for ", x$design, " computed with method of Yung and Liu.")
+        paste0("Power for ", x$Design, " computed with method of Yung and Liu.")
       },
       "rmst" = {
-        paste0("Power for ", x$design, " computed with method of Yung and Liu.")
+        paste0("Power for ", x$Design, " computed with method of Yung and Liu.")
       }
     )
   }
 
   ans <- x %>%
-    dplyr::mutate(design = design_mtd) %>%
     gt::gt() %>%
     gt::tab_header(title = title) %>%
     gt::tab_footnote(footnote = footnote, locations = gt::cells_title(group = "title"))
