@@ -25,11 +25,7 @@
 #' and enrollment pattern
 #' where the enrollment, failure and dropout rates changes over time.
 #'
-#' @param enroll_rate Piecewise constant enrollment rates by stratum and time period.
-#' @param fail_rate Piecewise constant control group failure rates,
-#'   duration for each piecewise constant period,
-#'   hazard ratio for experimental vs control,
-#'   and dropout rates by stratum and time period.
+#' @inheritParams ahr
 #' @param target_event The targeted number of events to be achieved.
 #' @param ratio Experimental:Control randomization ratio.
 #' @param interval An interval that is presumed to include the time at which
@@ -67,10 +63,12 @@
 #' # ------------------------#
 #' # check that result matches a finding using AHR()
 #' # Start by deriving an expected event count
-#' enroll_rate <- tibble::tibble(stratum = "All", duration = c(2, 2, 10), rate = c(3, 6, 9) * 5)
-#' fail_rate <- tibble::tibble(
-#'   stratum = "All", duration = c(3, 100), fail_rate = log(2) / c(9, 18),
-#'   hr = c(.9, .6), dropout_rate = rep(.001, 2)
+#' enroll_rate <- define_enroll_rate(duration = c(2, 2, 10), rate = c(3, 6, 9) * 5)
+#' fail_rate <- define_fail_rate(
+#'   duration = c(3, 100),
+#'   fail_rate = log(2) / c(9, 18),
+#'   hr = c(.9, .6),
+#'   dropout_rate = .001
 #' )
 #' total_duration <- 20
 #' xx <- ahr(enroll_rate, fail_rate, total_duration)
@@ -82,21 +80,21 @@
 #'   target_event = xx$event, interval = c(.5, 1.5) * xx$time
 #' )
 #' }
-expected_time <- function(enroll_rate = tibble::tibble(
-                            stratum = "All",
-                            duration = c(2, 2, 10),
-                            rate = c(3, 6, 9) * 5
-                          ),
-                          fail_rate = tibble::tibble(
-                            stratum = "All",
-                            duration = c(3, 100),
-                            fail_rate = log(2) / c(9, 18),
-                            hr = c(.9, .6),
-                            dropout_rate = rep(.001, 2)
-                          ),
-                          target_event = 150,
-                          ratio = 1,
-                          interval = c(.01, 100)) {
+expected_time <- function(
+    enroll_rate = define_enroll_rate(
+      duration = c(2, 2, 10),
+      rate = c(3, 6, 9) * 5
+    ),
+    fail_rate = define_fail_rate(
+      stratum = "All",
+      duration = c(3, 100),
+      fail_rate = log(2) / c(9, 18),
+      hr = c(.9, .6),
+      dropout_rate = rep(.001, 2)
+    ),
+    target_event = 150,
+    ratio = 1,
+    interval = c(.01, 100)) {
   # ----------------------------#
   #    check inputs             #
   # ----------------------------#
@@ -109,7 +107,7 @@ expected_time <- function(enroll_rate = tibble::tibble(
   #    build a help function    #
   # ----------------------------#
   # find the difference between  `AHR()` and different values of total_duration
-  foo <- function(x) {
+  event_diff <- function(x) {
     ans <- ahr(
       enroll_rate = enroll_rate, fail_rate = fail_rate,
       total_duration = x, ratio = ratio
@@ -121,7 +119,7 @@ expected_time <- function(enroll_rate = tibble::tibble(
   #       uniroot AHR()         #
   #    over total_duration      #
   # ----------------------------#
-  res <- try(uniroot(foo, interval))
+  res <- try(uniroot(event_diff, interval))
 
   if (inherits(res, "try-error")) {
     stop("expected_time(): solution not found!")
