@@ -252,15 +252,15 @@
 #'   upar = (xx %>% filter(bound == "upper"))$z,
 #'   lpar = -(xx %>% filter(bound == "upper"))$z
 #' )
-#'
-gs_design_npe <- function(theta = .1, theta0 = NULL, theta1 = NULL, # 3 theta
-                          info = 1, info0 = NULL, info1 = NULL, # 3 info
-                          info_scale = c("h0_h1_info", "h0_info", "h1_info"),
-                          alpha = 0.025, beta = .1,
-                          upper = gs_b, upar = qnorm(.975),
-                          lower = gs_b, lpar = -Inf,
-                          test_upper = TRUE, test_lower = TRUE, binding = FALSE,
-                          r = 18, tol = 1e-6) {
+gs_design_npe <- function(
+    theta = .1, theta0 = NULL, theta1 = NULL, # 3 theta
+    info = 1, info0 = NULL, info1 = NULL, # 3 info
+    info_scale = c("h0_h1_info", "h0_info", "h1_info"),
+    alpha = 0.025, beta = .1,
+    upper = gs_b, upar = qnorm(.975),
+    lower = gs_b, lpar = -Inf,
+    test_upper = TRUE, test_lower = TRUE, binding = FALSE,
+    r = 18, tol = 1e-6) {
   # --------------------------------------------- #
   #     check & set up parameters                 #
   # --------------------------------------------- #
@@ -491,9 +491,11 @@ gs_design_npe <- function(theta = .1, theta0 = NULL, theta1 = NULL, # 3 theta
   # combine probability under H0 and H1
   suppressMessages(
     ans <- ans_h1 %>%
-      full_join(ans_h0 %>%
-        select(analysis, bound, probability) %>%
-        dplyr::rename(probability0 = probability))
+      full_join(
+        ans_h0 %>%
+          select(analysis, bound, probability) %>%
+          dplyr::rename(probability0 = probability)
+      )
   )
 
   ans <- ans %>% select(analysis, bound, z, probability, probability0, theta, info_frac, info, info0, info1)
