@@ -38,7 +38,6 @@
 #' \if{html}{The contents of this section are shown in PDF user manual only.}
 #'
 #' @importFrom mvtnorm GenzBretz
-#' @importFrom tibble tibble
 #'
 #' @export
 #'
@@ -47,16 +46,13 @@
 #' library(mvtnorm)
 #' library(gsDesign)
 #' library(gsDesign2)
-#' library(tibble)
 #'
-#' enroll_rate <- tibble(
-#'   stratum = "All",
+#' enroll_rate <- define_enroll_rate(
 #'   duration = 12,
 #'   rate = 500 / 12
 #' )
 #'
-#' fail_rate <- tibble(
-#'   stratum = "All",
+#' fail_rate <- define_fail_rate(
 #'   duration = c(4, 100),
 #'   fail_rate = log(2) / 15, # median survival 15 month
 #'   hr = c(1, .6),
@@ -83,37 +79,36 @@
 #'   lpar = list(sf = gsDesign::sfLDOF, total_spend = 0.2)
 #' )
 #' }
-gs_power_combo <- function(enroll_rate = tibble(
-                             stratum = "all",
-                             duration = 12,
-                             rate = 500 / 12
-                           ),
-                           fail_rate = tibble(
-                             stratum = "all",
-                             duration = c(4, 100),
-                             fail_rate = log(2) / 15,
-                             hr = c(1, .6),
-                             dropout_rate = 0.001
-                           ),
-                           fh_test = rbind(
-                             data.frame(
-                               rho = 0, gamma = 0, tau = -1, test = 1,
-                               analysis = 1:3, analysis_time = c(12, 24, 36)
-                             ),
-                             data.frame(
-                               rho = c(0, 0.5), gamma = 0.5, tau = -1, test = 2:3,
-                               analysis = 3, analysis_time = 36
-                             )
-                           ),
-                           ratio = 1,
-                           binding = FALSE,
-                           upper = gs_b,
-                           upar = c(3, 2, 1),
-                           lower = gs_b,
-                           lpar = c(-1, 0, 1),
-                           algorithm = GenzBretz(maxpts = 1e5, abseps = 1e-5),
-                           ...) {
-  # Currently only support user defined lower and upper bound
+gs_power_combo <- function(
+    enroll_rate = define_enroll_rate(
+      duration = 12,
+      rate = 500 / 12
+    ),
+    fail_rate = define_fail_rate(
+      duration = c(4, 100),
+      fail_rate = log(2) / 15,
+      hr = c(1, .6),
+      dropout_rate = 0.001
+    ),
+    fh_test = rbind(
+      data.frame(
+        rho = 0, gamma = 0, tau = -1, test = 1,
+        analysis = 1:3, analysis_time = c(12, 24, 36)
+      ),
+      data.frame(
+        rho = c(0, 0.5), gamma = 0.5, tau = -1, test = 2:3,
+        analysis = 3, analysis_time = 36
+      )
+    ),
+    ratio = 1,
+    binding = FALSE,
+    upper = gs_b,
+    upar = c(3, 2, 1),
+    lower = gs_b,
+    lpar = c(-1, 0, 1),
+    algorithm = GenzBretz(maxpts = 1e5, abseps = 1e-5),
+    ...) {
+  # Currently only support user-defined lower and upper bound
   stopifnot(identical(upper, gs_b) | identical(upper, gs_spending_combo))
   stopifnot(identical(lower, gs_b) | identical(lower, gs_spending_combo))
 
