@@ -51,8 +51,10 @@
 #' @param info1 Statistical information under hypothesis used for
 #'   futility bound calculation if different from
 #'   `info`; impacts futility hypothesis bound calculation.
-#' @param info_scale The information scale for calculation,
-#'   default is 2, other options are 0 or 1.
+#' @param info_scale Information scale for calculation. Options are:
+#'   - `"h0_h1_info"` (default): variance under both null and alternative hypotheses is used.
+#'   - `"h0_info"`: variance under null hypothesis is used.
+#'   - `"h1_info"`: variance under alternative hypothesis is used.
 #' @param binding Indicator of whether futility bound is binding;
 #'   default of `FALSE` is recommended.
 #' @param upper Function to compute upper bound.
@@ -115,9 +117,6 @@
 #' }
 #' \if{html}{The contents of this section are shown in PDF user manual only.}
 #'
-#' @author Keaven Anderson \email{keaven_anderson@@merck.com}
-#'
-#' @importFrom tibble tibble
 #' @importFrom stats qnorm pnorm
 #'
 #' @export
@@ -203,7 +202,7 @@
 #' )
 gs_power_npe <- function(theta = .1, theta0 = NULL, theta1 = NULL, # 3 theta
                          info = 1, info0 = NULL, info1 = NULL, # 3 info
-                         info_scale = c(0, 1, 2),
+                         info_scale = c("h0_h1_info", "h0_info", "h1_info"),
                          upper = gs_b, upar = qnorm(.975),
                          lower = gs_b, lpar = -Inf,
                          test_upper = TRUE, test_lower = TRUE, binding = FALSE,
@@ -239,16 +238,13 @@ gs_power_npe <- function(theta = .1, theta0 = NULL, theta1 = NULL, # 3 theta
   }
 
   # set up info_scale
-  info_scale <- if (methods::missingArg(info_scale)) {
-    2
-  } else {
-    match.arg(as.character(info_scale), choices = 0:2)
-  }
-  if (info_scale == 0) {
+  info_scale <- match.arg(info_scale)
+
+  if (info_scale == "h0_info") {
     info <- info0
     info1 <- info0
   }
-  if (info_scale == 1) {
+  if (info_scale == "h1_info") {
     info <- info1
     info0 <- info1
   }
