@@ -32,7 +32,6 @@
 #' }
 #' \if{html}{The contents of this section are shown in PDF user manual only.}
 #'
-#' @importFrom tibble tibble
 #' @importFrom gsDesign gsDesign sfLDOF
 #' @importFrom dplyr left_join
 #'
@@ -42,16 +41,14 @@
 #' analysis, and bound.
 #'
 #' @examples
-#' library(tibble)
 #' library(gsDesign)
 #' library(gsDesign2)
 #'
 #' # set enrollment rates
-#' enroll_rate <- tibble(stratum = "All", duration = 12, rate = 500 / 12)
+#' enroll_rate <- define_enroll_rate(duration = 12, rate = 500 / 12)
 #'
 #' # set failure rates
-#' fail_rate <- tibble(
-#'   stratum = "All",
+#' fail_rate <- define_fail_rate(
 #'   duration = c(4, 100),
 #'   fail_rate = log(2) / 15, # median survival 15 month
 #'   hr = c(1, .6),
@@ -179,9 +176,9 @@
 #'   lpar = list(sf = gsDesign::sfLDOF, total_spend = 0.2)
 #' )
 #' }
-gs_power_wlr <- function(enroll_rate = tibble(stratum = "all", duration = c(2, 2, 10), rate = c(3, 6, 9)),
+gs_power_wlr <- function(enroll_rate = define_enroll_rate(duration = c(2, 2, 10), rate = c(3, 6, 9)),
                          fail_rate = tibble(
-                           stratum = "all", duration = c(3, 100), fail_rate = log(2) / c(9, 18),
+                           stratum = "All", duration = c(3, 100), fail_rate = log(2) / c(9, 18),
                            hr = c(.9, .6), dropout_rate = rep(.001, 2)
                          ),
                          event = c(30, 40, 50),
